@@ -1,4 +1,3 @@
-#!/usr/bin/python2.4
 #
 # Copyright 2008 Google Inc.
 #
@@ -23,13 +22,13 @@ Keyczart(ool) is a utility for creating and managing Keyczar keysets.
 import os
 import sys
 
-import errors
-import keyczar
-import keydata
-import keyinfo
-import readers
-import writers
-import util
+from keyczar import errors
+from keyczar import keydata
+from keyczar import keyinfo
+from keyczar import keys
+from keyczar import readers
+from keyczar import writers
+from keyczar import util
 
 KEYSETS = [('aes', keyinfo.DECRYPT_AND_ENCRYPT, None, None),
            ('aes-crypted', keyinfo.DECRYPT_AND_ENCRYPT, None, 'aes'),
