@@ -1,4 +1,3 @@
-#!/usr/bin/python2.4
 #
 # Copyright 2008 Google Inc.
 #
@@ -22,11 +21,11 @@ A Reader supports reading metadata and key info for key sets.
 
 import os                
 
-import errors
-import keydata
-import keyinfo
-import keys
-import util
+from keyczar import errors
+from keyczar import keydata
+from keyczar import keyinfo
+from keyczar import keys
+from keyczar import util
 
 def CreateReader(location):
   """Factory function for Reader's
@@ -114,6 +113,8 @@ class FileReader(Reader):
   @classmethod
   def CreateReader(cls, location):
     result = None
+    location = str(location) # This fixes the case in case the location is
+                             # an instance of Path (from django-environ)
     if os.path.exists(location):
       result = FileReader(location)
     return result
