@@ -380,6 +380,9 @@ def Base64WSDecode(s):
   @raise Base64DecodingError: If length of string (ignoring whitespace) is one
     more than a multiple of four.
   """
+  if isinstance(s, bytes):
+    s = s.decode()
+
   s = ''.join(s.splitlines())
   s = str(s.replace(" ", ""))  # kill whitespace, make string (not unicode)
   d = len(s) % 4
